@@ -84,9 +84,9 @@ FileTypesView::FileTypesView(QWidget *parent, const QVariantList &)
   l->addLayout( leftLayout );
 
   patternFilterLE = new KLineEdit(this);
-  patternFilterLE->setClearButtonShown(true);
+  patternFilterLE->setClearButtonEnabled(true);
   patternFilterLE->setTrapReturnKey(true);
-  patternFilterLE->setPlaceholderText(i18n("Find file type or filename pattern"));
+  patternFilterLE->setPlaceholderText(i18n("Search for file type or filename pattern..."));
   leftLayout->addWidget(patternFilterLE);
 
   connect(patternFilterLE, SIGNAL(textChanged(const QString &)),
